h11: A pure-Python, bring-your-own-I/O implementation of HTTP/1.1
=================================================================

Description
-----------

A pure-Python, bring-your-own-I/O implementation of HTTP/1.1

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/h11/

